import React, { useEffect, useState } from "react";
import {
  ModalForm,
  ProFormText,
  ProFormDependency,
} from "@ant-design/pro-components";
import md5 from "md5";
import { changeEmail } from "@/services/login";
import { useNavigate } from "react-router-dom";
import { useTranslation } from 'react-i18next';

export default (props) => {
  const { opEmail, setOpEmail, setEmail, hideEmail } = props;
  const navigate = useNavigate();
  const { t } = useTranslation();

  const onFinish = async (values) => {
    const data = {
      originEmail: values.email,
      newEmail: values.newEmail,
    };
    await changeEmail(data);
    let email = hideEmail(values?.newEmail);
    setEmail(email)
    setOpEmail(false)
    return true;
  };

  return (
    <ModalForm
      title={t('accountsettings.emailTitle')}
      width="480px"
      open={opEmail}
      modalProps={{
        onCancel: () => setOpEmail(false),
      }}
      onFinish={onFinish}
    >
      <ProFormText.Password
        label={t('accountsettings.emailInput1')}
        name="email"
        rules={[{ required: true }]}
      />
      <ProFormText.Password
        label={t('accountsettings.emailInput2')}
        name="newEmail"
        rules={[{ required: true }]}
      />

      <ProFormDependency name={["newEmail"]}>
        {({ newEmail }) => (
          <ProFormText.Password
            label={t('accountsettings.emailInputLabel')}
            name="newEmail2"
            rules={[
              { required: true, message: t('accountsettings.emailInputLabelRule') },
              () => ({
                validator (_, value) {
                  if (!value || value == newEmail) {
                    return Promise.resolve();
                  }

                  return Promise.reject(t('accountsettings.emailInputPromiseText'));
                },
              }),
            ]}
          />
        )}
      </ProFormDependency>
    </ModalForm>
  )
}